@@ -16,45 +16,45 @@ endpoint = TestClient(app)
 
 
 def test_service_description():
-    response = endpoint.get("/sparql", headers={"accept": "text/turtle"})
+    response = endpoint.get("/", headers={"accept": "text/turtle"})
     print(response.text.strip())
     assert response.status_code == 200
     # assert response.text.strip() == service_description
 
-    response = endpoint.post("/sparql", headers={"accept": "text/turtle"})
+    response = endpoint.post("/", headers={"accept": "text/turtle"})
     assert response.status_code == 200
     # assert response.text.strip() == service_description
 
     # Check for application/xml
-    response = endpoint.post("/sparql", headers={"accept": "application/xml"})
+    response = endpoint.post("/", headers={"accept": "application/xml"})
     assert response.status_code == 200
 
 
 def test_custom_concat_json():
-    response = endpoint.get("/sparql?query=" + urllib.parse.quote(label_select), headers={"accept": "application/json"})
+    response = endpoint.get("/?query=" + urllib.parse.quote(label_select), headers={"accept": "application/json"})
     # print(response.json())
     assert response.status_code == 200
     assert response.json()["results"]["bindings"][0]["label"]["value"] == "test value"
 
-    response = endpoint.post("/sparql", data="query=" + label_select, headers={"accept": "application/json"})
+    response = endpoint.post("/", data="query=" + label_select, headers={"accept": "application/json"})
     assert response.status_code == 200
     assert response.json()["results"]["bindings"][0]["label"]["value"] == "test value"
 
 
 def test_select_noaccept_xml():
-    response = endpoint.post("/sparql", data="query=" + label_select)
+    response = endpoint.post("/", data="query=" + label_select)
     assert response.status_code == 200
     # assert response.json()['results']['bindings'][0]['concat']['value'] == "Firstlast"
 
 
 def test_select_csv():
-    response = endpoint.post("/sparql", data="query=" + label_select, headers={"accept": "text/csv"})
+    response = endpoint.post("/", data="query=" + label_select, headers={"accept": "text/csv"})
     assert response.status_code == 200
     # assert response.json()['results']['bindings'][0]['concat']['value'] == "Firstlast"
 
 
 def test_fail_select_turtle():
-    response = endpoint.post("/sparql", data="query=" + label_select, headers={"accept": "text/turtle"})
+    response = endpoint.post("/", data="query=" + label_select, headers={"accept": "text/turtle"})
     assert response.status_code == 422
     # assert response.json()['results']['bindings'][0]['concat']['value'] == "Firstlast"
 
@@ -62,7 +62,7 @@ def test_fail_select_turtle():
 def test_concat_construct_turtle():
     # expected to return turtle
     response = endpoint.post(
-        "/sparql",
+        "/",
         data="query=" + label_construct,
         headers={"accept": "application/json"},
     )
@@ -73,7 +73,7 @@ def test_concat_construct_turtle():
 def test_concat_construct_xml():
     # expected to return turtle
     response = endpoint.post(
-        "/sparql",
+        "/",
         data="query=" + label_construct,
         headers={"accept": "application/xml"},
     )
@@ -81,15 +81,10 @@ def test_concat_construct_xml():
 
 
 def test_bad_request():
-    response = endpoint.get("/sparql?query=figarofigarofigaro", headers={"accept": "application/json"})
+    response = endpoint.get("/?query=figarofigarofigaro", headers={"accept": "application/json"})
     assert response.status_code == 400
 
 
-def test_redirect():
-    response = endpoint.get("/")
-    assert response.status_code == 200
-
-
 label_select = """PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 SELECT ?label WHERE {
     ?s rdfs:label ?label .
